[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- simplify.Authentication: Holds authentication information used when accessing the API.
- simplify.constants.Constants: Holds constant values.
- simplify.domain.Domain
- simplify.BadRequestError.FieldError: Represents a single error in a field of data sent in a request to the API.
- simplify.Http
- simplify.Jws
- simplify.PaymentsApi
- object: The most base type
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - simplify.ApiError: Base class for all API errors.
      - exceptions.StandardError: Base class for all standard Python exceptions that do not represent interpreter exiting.
        - exceptions.ValueError: Inappropriate argument value (of correct type).
          - simplify.IllegalArgumentError: Error raised when passing illegal arguments.
  - simplify.domain.DomainFactory
  - json.encoder.JSONEncoder: Extensible JSON <http://json.org> encoder for Python data structures.
    - simplify.domain.PaymentObjectEncoder